@@ -52,6 +52,7 @@
 #include "string_enumeration.hpp"
 #include "string_map.hpp"
 #include "word_list.hpp"
+#include "istream_enumeration.hpp"
 
 #include "string_list.hpp"
 #include "speller_impl.hpp"
@@ -204,10 +205,11 @@ static const ModeAbrv mode_abrvs[] = {
   {'e', "mode=email", N_("enter Email mode.")},
   {'H', "mode=html",  N_("enter HTML mode.")},
   {'t', "mode=tex",   N_("enter TeX mode.")},
-  {'n', "mode=nroff", N_("enter Nroff mode.")}
+  {'n', "mode=nroff", N_("enter Nroff mode.")},
+  {'M', "mode=markdown", N_("enter Markdown mode.")},
 };
 
-static const ModeAbrv *  mode_abrvs_end = mode_abrvs + 4;
+static const ModeAbrv *  mode_abrvs_end = mode_abrvs + sizeof(mode_abrvs)/sizeof(ModeAbrv);
 
 const PossibleOption * find_option(char c) {
   const PossibleOption * i = possible_options;
@@ -675,7 +677,7 @@ void status_fun(void * d, Token, int correct)
     if (ci->compound)
       COUT.put("-\n");
     else if (ci->pre_flag || ci->suf_flag)
-      COUT.printf("+ %s\n", p->oconv(ci->word.str()));
+      COUT.printf("+ %s\n", p->oconv(ci->word.str, ci->word.len));
     else
       COUT.put("*\n");
   }
@@ -755,6 +757,7 @@ void pipe()
       buf.push_back(static_cast<char>(c));
     buf.push_back('\n'); // always add new line so strlen > 0
     buf.push_back('\0');
+    //CERR.printf("%s", buf.data());
     line = buf.data();
     ignore = 0;
     switch (line[0]) {
@@ -873,11 +876,11 @@ void pipe()
           guess.clear();
           if (ci->pre_add && ci->pre_add[0])
             guess.append(ci->pre_add, ci->pre_add_len).append('+');
-          guess.append(ci->word);
+          guess.append(ci->word.str, ci->word.len);
           if (ci->pre_strip_len > 0) 
-            guess.append('-').append(ci->word.str(), ci->pre_strip_len);
+            guess.append('-').append(ci->word.str, ci->pre_strip_len);
           if (ci->suf_strip_len > 0) 
-            guess.append('-').append(ci->word.str() + ci->word.size() - ci->suf_strip_len, 
+            guess.append('-').append(ci->word.str + ci->word.len - ci->suf_strip_len, 
                                      ci->suf_strip_len);
           if (ci->suf_add && ci->suf_add[0])
             guess.append('+').append(ci->suf_add, ci->suf_add_len);
@@ -1443,24 +1446,6 @@ void print_ver () {
 // module
 //
 
-class IstreamEnumeration : public StringEnumeration {
-  FStream * in;
-  String data;
-public:
-  IstreamEnumeration(FStream & i) : in(&i) {}
-  IstreamEnumeration * clone() const {
-    return new IstreamEnumeration(*this);
-  }
-  void assign (const StringEnumeration * other) {
-    *this = *static_cast<const IstreamEnumeration *>(other);
-  }
-  Value next() {
-    if (!in->getline(data)) return 0;
-    else return data.c_str();
-  }
-  bool at_end() const {return *in;}
-};
-
 ///////////////////////////
 //
 // clean
@@ -1608,7 +1593,7 @@ void personal () {
     // FIXME: This is currently broken
 
     Config * config = options;
-    Dictionary * per = new_default_writable_dict();
+    Dictionary * per = new_default_writable_dict(*config);
     EXIT_ON_ERR(per->load(config->retrieve("personal-path"), *config));
     StackPtr<WordEntryEnumeration> els(per->detailed_elements());
     StackPtr<Convert> conv(setup_conv(per->lang(), config));
@@ -1670,7 +1655,7 @@ void repl() {
 
     // FIXME: This is currently broken
 
-    ReplacementDict * repl = new_default_replacement_dict();
+    ReplacementDict * repl = new_default_replacement_dict(*options);
     repl->load(options->retrieve("repl-path"), *options);
     StackPtr<WordEntryEnumeration> els(repl->detailed_elements());
     
@@ -1734,7 +1719,7 @@ void munch()
     COUT << word;
     for (const aspeller::CheckInfo * ci = gi.head; ci; ci = ci->next)
     {
-      COUT << ' ' << oconv(ci->word) << '/';
+      COUT << ' ' << oconv(ci->word.str, ci->word.len) << '/';
       if (ci->pre_flag != 0) COUT << oconv(static_cast<char>(ci->pre_flag));
       if (ci->suf_flag != 0) COUT << oconv(static_cast<char>(ci->suf_flag));
     }
@@ -2005,7 +1990,7 @@ void munch_list_simple()
     while (ci)
     { {
       // check if the base word is in the dictionary
-      SML_Table::iterator b = table.find(ci->word);
+      SML_Table::iterator b = table.find(ci->word.str);
       if (b == table.end()) goto cont;
 
       // check if all the words once expanded are in the dictionary
@@ -2015,15 +2000,15 @@ void munch_list_simple()
       if (ci->pre_flag != 0) flags += ci->pre_flag;
       if (ci->suf_flag != 0) flags += ci->suf_flag;
       exp_buf.reset();
-      exp_list = lang->expand(ci->word, flags, exp_buf);
+      exp_list = lang->expand(ci->word.str, flags, exp_buf);
       for (WordAff * q = exp_list; q; q = q->next) {
         if (!table.have(q->word)) goto cont;
       }
 
       // the base word and flags are valid, now keep the one with the
       // smallest base word
-      if (ci->word.size() < min_base_size) {
-        min_base_size = ci->word.size();
+      if (ci->word.len < min_base_size) {
+        min_base_size = ci->word.len;
         best = ci;
       }
 
@@ -2033,7 +2018,7 @@ void munch_list_simple()
     // now add the base to the keep list if one exists
     // otherwise just keep the original word
     if (best) {
-      SML_Table::iterator b = table.find(best->word);
+      SML_Table::iterator b = table.find(best->word.str);
       assert(b != table.end());
       if (best->pre_flag) add_affix(b, best->pre_flag);
       if (best->suf_flag) add_affix(b, best->suf_flag);
@@ -2366,7 +2351,7 @@ void munch_list_complete(bool multi, bool simplify)
     while (ci)
     { {
       // check if the base word is in the dictionary
-      CML_Table::iterator b = table.find(ci->word);
+      CML_Table::iterator b = table.find(ci->word.str);
       if (b == table.end()) goto cont;
 
       // check if all the words once expanded are in the dictionary
@@ -2376,7 +2361,7 @@ void munch_list_complete(bool multi, bool simplify)
       else if (ci->suf_flag != 0) flags[0] = ci->suf_flag;
       flags[1] = '\0';
       exp_buf.reset();
-      exp_list = lang->expand(ci->word, flags, exp_buf);
+      exp_list = lang->expand(ci->word.str, flags, exp_buf);
       for (WordAff * q = exp_list; q; q = q->next) {
         if (!table.have(q->word)) goto cont;
       }
